==> honeypots-0.5.tar.gz: honeypots-0.5/honeypots/testing_all.py <==
from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, server_arguments, clean_all
from time import sleep

print("Testing QDNSServer")
qdnsserver = QDNSServer()
qdnsserver.run_server(process=True,auto=True)
sleep(1)
qdnsserver.test_server()
qdnsserver.kill_server()
clean_all()

print("Testing QFTPServer")
qftpserver = QFTPServer()
qftpserver.run_server(process=True,auto=True)
sleep(1)
qftpserver.test_server()
qftpserver.kill_server()
clean_all()

print("Testing QHTTPProxyServer")
qhttpproxyserver = QHTTPProxyServer()
qhttpproxyserver.run_server(process=True,auto=True)
sleep(1)
qhttpproxyserver.test_server()
qhttpproxyserver.kill_server()
clean_all()

print("Testing QHTTPServer")
qhttpserver = QHTTPServer()
qhttpserver.run_server(process=True,auto=True)
sleep(1)
qhttpserver.test_server()
qhttpserver.kill_server()
clean_all()

print("Testing QHTTPSServer")
qhttpsserver = QHTTPSServer()
qhttpsserver.run_server(process=True,auto=True)
sleep(1)
qhttpsserver.test_server()
qhttpsserver.kill_server()
clean_all()

print("Testing QIMAPServer")
qimapserver = QIMAPServer()
qimapserver.run_server(process=True,auto=True)
sleep(1)
qimapserver.test_server()
qimapserver.kill_server()
clean_all()

print("Testing QMysqlServer")
qmysqlserver = QMysqlServer()
qmysqlserver.run_server(process=True,auto=True)
sleep(1)
qmysqlserver.test_server()
qmysqlserver.kill_server()
clean_all()

print("Testing QTPOP3Server")
qpop3server = QPOP3Server()
qpop3server.run_server(process=True,auto=True)
sleep(1)
qpop3server.test_server()
qpop3server.kill_server()
clean_all()

print("Testing QPostgresServer")
qpostgresserver = QPostgresServer()
qpostgresserver.run_server(process=True,auto=True)
sleep(1)
qpostgresserver.test_server()
qpostgresserver.kill_server()
clean_all()

print("Testing QRedisServer")
qredisserver = QRedisServer()
qredisserver.run_server(process=True,auto=True)
sleep(1)
qredisserver.test_server()
qredisserver.kill_server()
clean_all()

print("Testing QSMBServer")
qsmbserver = QSMBServer()
qsmbserver.run_server(process=True,auto=True)
sleep(1)
qsmbserver.test_server()
qsmbserver.kill_server()
clean_all()

print("Testing QSMTPServer")
qsmtpserver = QSMTPServer()
qsmtpserver.run_server(process=True,auto=True)
sleep(1)
qsmtpserver.test_server()
qsmtpserver.kill_server()
clean_all()

print("Testing QSOCKS5Server")
qsocks5server = QSOCKS5Server()
qsocks5server.run_server(process=True,auto=True)
sleep(1)
qsocks5server.test_server()
qsocks5server.kill_server()
clean_all()

print("Testing QSSHServer")
qsshserver = QSSHServer()
qsshserver.run_server(process=True,auto=True)
sleep(1)
qsshserver.test_server()
qsshserver.kill_server()
clean_all()

print("Testing QTelnetServer")
qtelnetserver = QTelnetServer()
qtelnetserver.run_server(process=True,auto=True)
sleep(1)
qtelnetserver.test_server()
qtelnetserver.kill_server()
clean_all()

print("Testing QVNCServer")
qvncserver = QVNCServer()
qvncserver.run_server(process=True,auto=True)
sleep(1)
qvncserver.test_server()
qvncserver.kill_server()
clean_all()

==> honeypots-0.11.tar.gz: honeypots-0.11/honeypots/testing_all.py <==
from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPSServer, QHTTPServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, clean_all
from time import sleep


print("Testing QSOCKS5Server")
qsocks5server = QSOCKS5Server()
qsocks5server.run_server(process=True, auto=True)
sleep(1)
qsocks5server.test_server()
qsocks5server.kill_server()
clean_all()

print("Testing QSSHServer")
qsshserver = QSSHServer()
qsshserver.run_server(process=True, auto=True)
sleep(1)
qsshserver.test_server()
qsshserver.kill_server()
clean_all()

print("Testing QTelnetServer")
qtelnetserver = QTelnetServer()
qtelnetserver.run_server(process=True, auto=True)
sleep(1)
qtelnetserver.test_server()
qtelnetserver.kill_server()
clean_all()

print("Testing QVNCServer")
qvncserver = QVNCServer()
qvncserver.run_server(process=True, auto=True)
sleep(1)
qvncserver.test_server()
qvncserver.kill_server()
clean_all()


exit()

print("Testing QDNSServer")
qdnsserver = QDNSServer()
qdnsserver.run_server(process=True, auto=True)
sleep(1)
qdnsserver.test_server()
qdnsserver.kill_server()
clean_all()

print("Testing QFTPServer")
qftpserver = QFTPServer()
qftpserver.run_server(process=True, auto=True)
sleep(1)
qftpserver.test_server()
qftpserver.kill_server()
clean_all()

print("Testing QHTTPProxyServer")
qhttpproxyserver = QHTTPProxyServer()
qhttpproxyserver.run_server(process=True, auto=True)
sleep(1)
qhttpproxyserver.test_server()
qhttpproxyserver.kill_server()
clean_all()

print("Testing QHTTPServer")
qhttpserver = QHTTPServer()
qhttpserver.run_server(process=True, auto=True)
sleep(1)
qhttpserver.test_server()
qhttpserver.kill_server()
clean_all()

print("Testing QHTTPSServer")
qhttpsserver = QHTTPSServer()
qhttpsserver.run_server(process=True, auto=True)
sleep(1)
qhttpsserver.test_server()
qhttpsserver.kill_server()
clean_all()

print("Testing QIMAPServer")
qimapserver = QIMAPServer()
qimapserver.run_server(process=True, auto=True)
sleep(1)
qimapserver.test_server()
qimapserver.kill_server()
clean_all()

print("Testing QMysqlServer")
qmysqlserver = QMysqlServer()
qmysqlserver.run_server(process=True, auto=True)
sleep(1)
qmysqlserver.test_server()
qmysqlserver.kill_server()
clean_all()

print("Testing QTPOP3Server")
qpop3server = QPOP3Server()
qpop3server.run_server(process=True, auto=True)
sleep(1)
qpop3server.test_server()
qpop3server.kill_server()
clean_all()

print("Testing QPostgresServer")
qpostgresserver = QPostgresServer()
qpostgresserver.run_server(process=True, auto=True)
sleep(1)
qpostgresserver.test_server()
qpostgresserver.kill_server()
clean_all()

print("Testing QRedisServer")
qredisserver = QRedisServer()
qredisserver.run_server(process=True, auto=True)
sleep(1)
qredisserver.test_server()
qredisserver.kill_server()
clean_all()

print("Testing QSMBServer")
qsmbserver = QSMBServer()
qsmbserver.run_server(process=True, auto=True)
sleep(1)
qsmbserver.test_server()
qsmbserver.kill_server()
clean_all()

print("Testing QSMTPServer")
qsmtpserver = QSMTPServer()
qsmtpserver.run_server(process=True, auto=True)
sleep(1)
qsmtpserver.test_server()
qsmtpserver.kill_server()
clean_all()

print("Testing QSOCKS5Server")
qsocks5server = QSOCKS5Server()
qsocks5server.run_server(process=True, auto=True)
sleep(1)
qsocks5server.test_server()
qsocks5server.kill_server()
clean_all()

print("Testing QSSHServer")
qsshserver = QSSHServer()
qsshserver.run_server(process=True, auto=True)
sleep(1)
qsshserver.test_server()
qsshserver.kill_server()
clean_all()

print("Testing QTelnetServer")
qtelnetserver = QTelnetServer()
qtelnetserver.run_server(process=True, auto=True)
sleep(1)
qtelnetserver.test_server()
qtelnetserver.kill_server()
clean_all()

print("Testing QVNCServer")
qvncserver = QVNCServer()
qvncserver.run_server(process=True, auto=True)
sleep(1)
qvncserver.test_server()
qvncserver.kill_server()
clean_all()
